==> smile-0.6.4.tar.gz: smile/timeline.h <==
#ifndef TIMELINE_H
#define TIMELINE_H
#include <QFrame>
#include <QLabel>
#include "audio_editor.h"

class timeline : public QFrame
{
	Q_OBJECT
	public:
		timeline(QWidget * parent);
		QWidget *myparent;
		QString wl_pathname;
		int drop_x;
		int drop_y;
		QLabel *pntinsert;
		int max_diapo;
	        QMovie *insert_movie;
		int lengthtimeline;
		int postimeline;
		int tabposition;
		int zik_number;
		audio_editor *zik_1;

		QAction *removeDiapo;
		QAction *editDiapo;
		QAction *copyDiapo;
		QAction *pasteDiapo;
		QAction *addaudioDiapo;
		QAction *synaudioDiapo;
		QAction *delaudioDiapo;
		QAction *stopaudioDiapo;
		QAction *melangeDiapo;
	public slots:
		void deletethis();
		void editthis();
		void copythis();
		void pastethis();
		void addaudio();
		void syncaudio();
		void delaudio();
		void stopaudio();
		void melange();
	private:
		void dragLeaveEvent ( QDragLeaveEvent * event );
	signals:
		void godrop();
		void move_left();
		void move_right();
		void dia_delete();
		void dia_edit();
		void dia_copy();
		void dia_paste();
		void dia_melange();
		void slice(int);
		void s_addaudio();
		void s_syncaudio();
		void s_delaudio();
		void s_stopaudio();
	protected:
		void contextMenuEvent(QContextMenuEvent *event);
		void dragEnterEvent(QDragEnterEvent *event);
		void dropEvent(QDropEvent *event);
		void dragMoveEvent(QDragMoveEvent *event);
		void mouseMoveEvent(QMouseEvent *event);
		void wheelEvent(QWheelEvent *event);
		Qt::DropActions supportedDropActions () const;
};
#endif

==> smile-0.6.7.tar.gz: smile/timeline.h <==
#ifndef TIMELINE_H
#define TIMELINE_H
#include <QFrame>
#include <QLabel>
#include "audio_editor.h"

class timeline : public QFrame
{
	Q_OBJECT
	public:
		timeline(QWidget * parent);
		QWidget *myparent;
		QString wl_pathname;
		int drop_x;
		int drop_y;
		QLabel *pntinsert;
		int max_diapo;
	        QMovie *insert_movie;
		int lengthtimeline;
		int postimeline;
		int tabposition;
		int zik_number;
		audio_editor *zik_1;

		QAction *removeDiapo;
		QAction *editDiapo;
		QAction *copyDiapo;
		QAction *pasteDiapo;
		QAction *addaudioDiapo;
		QAction *synaudioDiapo;
		QAction *delaudioDiapo;
		QAction *stopaudioDiapo;
		QAction *melangeDiapo;
	public slots:
		void deletethis();
		void editthis();
		void copythis();
		void pastethis();
		void addaudio();
		void syncaudio();
		void delaudio();
		void stopaudio();
		void melange();
	private:
		void dragLeaveEvent ( QDragLeaveEvent * event );
	signals:
		void godrop();
		void move_left();
		void move_right();
		void dia_delete();
		void dia_edit();
		void dia_copy();
		void dia_paste();
		void dia_melange();
		void slice(int);
		void s_addaudio();
		void s_syncaudio();
		void s_delaudio();
		void s_stopaudio();
	protected:
		void contextMenuEvent(QContextMenuEvent *event);
		void dragEnterEvent(QDragEnterEvent *event);
		void dropEvent(QDropEvent *event);
		void dragMoveEvent(QDragMoveEvent *event);
		//void mouseMoveEvent(QMouseEvent *event);
		void wheelEvent(QWheelEvent *event);
		Qt::DropActions supportedDropActions () const;
};
#endif
